@@ -1,10 +1,15 @@
-''' The __init__ for the PyImbalReg '''
+'''Making the packages
 
-__version__ = "0.0.2"
+The __init__ for the PyImbalReg
+'''
+
+__version__ = "0.0.3"
 
 
 from .DataHandler import *
 from .RU import RandomUndersampling
 from .RO import RandomOversampling
 from .GN import GaussianNoise
-from .WERCS import WERCS
\ No newline at end of file
+from .WERCS import WERCS
+from .train_test_split import train_test_split
+from .GNHF import GNHF
\ No newline at end of file
